@@ -86,7 +86,7 @@
 #define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGCORE_NO_DEPRECATED
-#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
 #  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -145,6 +145,12 @@
 #else
 #  define KCONFIGCORE_DEPRECATED_VERSION_5_89(text)
 #endif
+
+#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x56700
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_103(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_103(text)
+#endif
 #define KCONFIGCORE_DEPRECATED_VERSION_4(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION_5(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -211,7 +217,7 @@
 #define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGCORE_NO_DEPRECATED
-#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
 #  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -221,7 +227,7 @@
 #  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -270,6 +276,12 @@
 #else
 #  define KCONFIGCORE_DEPRECATED_VERSION_5_89(text)
 #endif
+
+#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x56700
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_103(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_103(text)
+#endif
 #define KCONFIGCORE_DEPRECATED_VERSION_4(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION_5(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
